@@ -113,6 +113,104 @@ def test_upload_license(client, requests_mock):
     assert license_info == payload
 
 
+def test_list_resource_containers_not_supported(client, requests_mock):
+    requests_mock.get(
+        f"{API_BASE}/buildInfo",
+        headers={"Content-Type": "application/json"},
+        json={
+            "payload": {
+                "specVersion": "7.6.0",
+                "buildNumber": "branch: main f2731e315ee137cf94c48e5f2fa431777fe49cef",
+                "platformVersion": "8.22.0"
+            },
+            "errorMessages": []
+        },
+    )
+    with pytest.raises(OperationNotSupported):
+        client.list_resource_containers()
+
+
+def test_list_resource_containers(client, requests_mock):
+    requests_mock.get(
+        f"{API_BASE}/buildInfo",
+        headers={"Content-Type": "application/json"},
+        json={
+            "payload": {
+                "specVersion": "7.7.0",
+                "buildNumber": "branch: main f2731e315ee137cf94c48e5f2fa431777fe49cef",
+                "platformVersion": "8.23.0"
+            },
+            "errorMessages": []
+        },
+    )
+
+    requests_mock.get(
+        f"{API_EXPERIMENTAL}/textanalysis/containers",
+        headers={"Content-Type": "application/json"},
+        json={
+            "payload": {
+                "containers": [
+                    {
+                        "name": "container",
+                        "scope": "GLOBAL"
+                    }
+                ]
+            },
+            "errorMessages": []
+        }
+    )
+
+    actual_containers = client.list_resource_containers()
+    assert len(actual_containers) == 1
+    actual_container = actual_containers[0]
+    assert actual_container.name == "container"
+
+
+def test_create_resource_container(client, requests_mock):
+    requests_mock.get(
+        f"{API_BASE}/buildInfo",
+        headers={"Content-Type": "application/json"},
+        json={
+            "payload": {
+                "specVersion": "7.7.0",
+                "buildNumber": "branch: main f2731e315ee137cf94c48e5f2fa431777fe49cef",
+                "platformVersion": "8.23.0"
+            },
+            "errorMessages": []
+        },
+    )
+
+    requests_mock.post(
+        f"{API_EXPERIMENTAL}/textanalysis/containers",
+        headers={"Content-Type": "application/json"},
+        json={
+            "payload": {
+                "containerName": "container",
+                "scope": "GLOBAL",
+                "resources": [
+                    {
+                        "relativePath": "text3.txt"
+                    },
+                    {
+                        "relativePath": "text2.txt"
+                    },
+                    {
+                        "relativePath": "text1.txt"
+                    },
+                    {
+                        "relativePath": "sub/text4.txt"
+                    }
+                ]
+            },
+            "errorMessages": []
+        }
+    )
+
+    resource_zip_file = Path(TEST_DIRECTORY) / "resources" / "zip_test" / "zip_test.zip"
+    actual_resource_container = client.create_resource_container("container", resource_zip_file)
+    assert actual_resource_container.name == "container"
+
+
 def test_generate_api_token(client, requests_mock):
     requests_mock.post(
         f"{API_BASE}/users/admin/apitoken",
@@ -710,6 +808,61 @@ def test_get_terminology_import_info(client, requests_mock):
     assert response["state"] == "COMPLETED"
 
 
+def test_concept_autosuggest(client, requests_mock):
+    project_name = "test_project"
+    terminology_name = "ICD10GM_2021"
+    # Simulierte Antwort des concept_autosuggest Endpunkts
+    response_json = {
+        "payload": {
+            "suggestions": [
+                {
+                    "matchedTerm": "C50-C50",
+                    "language": "de",
+                    "conceptId": "C50-C50",
+                    "preferredTerm": "Bösartige Neubildungen der Brustdrüse [Mamma]",
+                },
+                {
+                    "matchedTerm": "C50.-",
+                    "language": "de",
+                    "conceptId": "C50.-",
+                    "preferredTerm": "Bösartige Neubildung der Brustdrüse [Mamma]",
+                },
+                {
+                    "matchedTerm": "C50.0",
+                    "language": "de",
+                    "conceptId": "C50.0",
+                    "preferredTerm": "Bösartige Neubildung: Brustwarze und Warzenhof",
+                },
+                {
+                    "matchedTerm": "C50.1",
+                    "language": "de",
+                    "conceptId": "C50.1",
+                    "preferredTerm": "Bösartige Neubildung: Zentraler Drüsenkörper der Brustdrüse",
+                },
+                {
+                    "matchedTerm": "C50.2",
+                    "language": "de",
+                    "conceptId": "C50.2",
+                    "preferredTerm": "Bösartige Neubildung: Oberer innerer Quadrant der Brustdrüse",
+                },
+            ]
+        },
+        "errorMessages": [],
+    }
+    endpoint = f"terminology/projects/{project_name}/terminologies/{terminology_name}/conceptAutosuggest"
+    full_url = f"{API_EXPERIMENTAL}/{endpoint}"
+    requests_mock.post(full_url, json=response_json)
+
+    project = client.get_project(project_name)
+    terminology = project.get_terminology(terminology_name)
+    result = terminology.concept_autosuggest(
+        query="C50", include_concept_identifier=True, max_suggestions=5
+    )
+    suggestions = result.get("suggestions", [])
+    assert len(suggestions) == 5
+    assert suggestions[0]["conceptId"].startswith("C50")
+
+
 def test_analyse_text(client, requests_mock):
     requests_mock.post(
         f"{API_BASE}/textanalysis/projects/{PROJECT_NAME}/pipelines/discharge/analyseText",
